==> ogre-docs-1.11.2-1-x86_64.pkg.tar.xz: usr/share/doc/OGRE/api/html/search/variables_14.js <==
var searchData=
[
  ['u',['u',['../struct_ogre_1_1_texture_unit_state_1_1_u_v_w_addressing_mode.html#a4b32e713a976b9e0fce84cf6b8f4ab1b',1,'Ogre::TextureUnitState::UVWAddressingMode::u()'],['../group___hlms.html#ga52a96b53f1912e917960efcb0b1212da',1,'Ogre::PbsMaterial::TextureAddressing::u()']]],
  ['uintbuffersize',['uintBufferSize',['../struct_ogre_1_1_gpu_named_constants.html#aa78a9520e9515038318893626480112c',1,'Ogre::GpuNamedConstants']]],
  ['uncompressedsize',['uncompressedSize',['../struct_ogre_1_1_file_info.html#a66c7bf4f59feb619016a5c70e4ded4ee',1,'Ogre::FileInfo']]],
  ['uninitialized_5fcollapse_5fcost',['UNINITIALIZED_COLLAPSE_COST',['../struct_ogre_1_1_lod_data.html#af95ac40c4f3bdd402aa2e0cc1e25fc9c',1,'Ogre::LodData']]],
  ['unit_5fscale',['UNIT_SCALE',['../class_ogre_1_1_vector2.html#a165a67053e61b0733746453ce9ee5edb',1,'Ogre::Vector2::UNIT_SCALE()'],['../class_ogre_1_1_vector3.html#a6a27e8a3a9156701f586afeed1516fb8',1,'Ogre::Vector3::UNIT_SCALE()']]],
  ['unit_5fx',['UNIT_X',['../class_ogre_1_1_vector2.html#a1c2d210b2756d07375b0cf9f01835496',1,'Ogre::Vector2::UNIT_X()'],['../class_ogre_1_1_vector3.html#a0c21d1f120c5eab83aa966e5de1df311',1,'Ogre::Vector3::UNIT_X()']]],
  ['unit_5fy',['UNIT_Y',['../class_ogre_1_1_vector2.html#ad20c8c58c9345a71743416bad82cb5e3',1,'Ogre::Vector2::UNIT_Y()'],['../class_ogre_1_1_vector3.html#a8d1a1f7af535bcc8d9c78b1732bc1b90',1,'Ogre::Vector3::UNIT_Y()']]],
  ['unit_5fz',['UNIT_Z',['../class_ogre_1_1_vector3.html#ad25aed2e9367cfa879d3e3c231c5a136',1,'Ogre::Vector3']]],
  ['unknown',['unknown',['../structbsp__face__t.html#adf2e01928d721064f72ba3f9c2e6a2fd',1,'bsp_face_t']]],
  ['updatefrom',['updateFrom',['../struct_ogre_1_1_volume_1_1_chunk_parameters.html#aeefacd1d618206fcb432ed947b58e06e',1,'Ogre::Volume::ChunkParameters']]],
  ['updateto',['updateTo',['../struct_ogre_1_1_volume_1_1_chunk_parameters.html#afe30999e8cc71a1f48d87d68bf43059d',1,'Ogre::Volume::ChunkParameters']]],
  ['usebackgroundqueue',['useBackgroundQueue',['../struct_ogre_1_1_lod_config_1_1_advanced.html#af0b0ebeed034ed3d63ea1bfc3c36fab0',1,'Ogre::LodConfig::Advanced']]],
  ['usecompression',['useCompression',['../struct_ogre_1_1_lod_config_1_1_advanced.html#a170e01ea28652c19ec4d610c0b491ab7',1,'Ogre::LodConfig::Advanced']]],
  ['usedcount',['usedCount',['../struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#a433c84c8a42109d4f1e0987c063b0eee',1,'Ogre::Lod0Stripifier::RemapInfo']]],
  ['usefullscreen',['useFullScreen',['../struct_ogre_1_1_render_window_description.html#a5809e1727a29bbc2737e090ab338c6a7',1,'Ogre::RenderWindowDescription']]],
  ['useglobalinstancingvertexbufferisavailable',['useGlobalInstancingVertexBufferIsAvailable',['../class_ogre_1_1_render_operation.html#a58effcf80fb468f10360aeab08d3c32e',1,'Ogre::RenderOperation']]],
  ['useindexes',['useIndexes',['../class_ogre_1_1_render_operation.html#ae12d3ff9f224f21738fa50f832484f3d',1,'Ogre::RenderOperation']]],
  ['user_5ftype_5fmask_5flimit',['USER_TYPE_MASK_LIMIT',['../class_ogre_1_1_scene_manager.html#a01d4bf3c6e81fddcfc96ec3f2714c8ac',1,'Ogre::SceneManager']]],
  ['uservalue',['userValue',['../struct_ogre_1_1_mesh_lod_usage.html#a114e1bc321b7b64f5bc931a30fea4dfe',1,'Ogre::MeshLodUsage']]],
  ['usesharedvertexbuffer',['useSharedVertexBuffer',['../struct_ogre_1_1_lod_input_buffer_1_1_submesh.html#a575926e31feb1cc9bfebab8a13fded97',1,'Ogre::LodInputBuffer::Submesh']]],
  ['usesharedvertices',['useSharedVertices',['../class_ogre_1_1_sub_mesh.html#a931e3764e3bf1c3ef7431fc852770fb1',1,'Ogre::SubMesh']]],
  ['usevertexnormals',['useVertexNormals',['../struct_ogre_1_1_lod_config_1_1_advanced.html#aa510662a645fab3ef85ef4b1cde1a7a2',1,'Ogre::LodConfig::Advanced']]],
  ['uvcount',['UvCount',['../group___hlms.html#ga6fb7180418134082f76431b6bedcdd62',1,'Ogre::DefaultProperties']]],
  ['uvcount0',['UvCount0',['../group___hlms.html#gaedab28b78e0ebc409cf4d3101a67af7c',1,'Ogre::DefaultProperties']]],
  ['uvcount1',['UvCount1',['../group___hlms.html#ga5483f4f1b66ed2f133e440367cab75d4',1,'Ogre::DefaultProperties']]],
  ['uvcount2',['UvCount2',['../group___hlms.html#ga47f8e565c0a2e5ccf4e24bc67e2706d2',1,'Ogre::DefaultProperties']]],
  ['uvcount3',['UvCount3',['../group___hlms.html#ga8439416753af467b73c4e8bbb70d44cc',1,'Ogre::DefaultProperties']]],
  ['uvcount4',['UvCount4',['../group___hlms.html#ga0fc23b194d9420e5b0b3c75b279e2e3c',1,'Ogre::DefaultProperties']]],
  ['uvcount5',['UvCount5',['../group___hlms.html#ga124b240dea2798f2c50151181e6c5678',1,'Ogre::DefaultProperties']]],
  ['uvcount6',['UvCount6',['../group___hlms.html#gaeb807ee11ed0edae44300ee8ef38bcf5',1,'Ogre::DefaultProperties']]],
  ['uvcount7',['UvCount7',['../group___hlms.html#gadd3f91003e10f2fe9efacecb4faed9f6',1,'Ogre::DefaultProperties']]],
  ['uvcountptrs',['UvCountPtrs',['../group___hlms.html#ga664c90b0d92acd45c06a39a3f259ad49',1,'Ogre::DefaultProperties']]],
  ['uvrect',['uvRect',['../struct_ogre_1_1_font_1_1_glyph_info.html#a46b20f8f199e3d2f698aa44a6553ab50',1,'Ogre::Font::GlyphInfo']]]
];

==> ogre-docs-1.11.5-1-x86_64.pkg.tar.xz: usr/share/doc/OGRE/api/html/search/variables_14.js <==
var searchData=
[
  ['u',['u',['../struct_ogre_1_1_sampler_1_1_u_v_w_addressing_mode.html#a1c5a9ff33cf02123738072572897df10',1,'Ogre::Sampler::UVWAddressingMode::u()'],['../group___hlms.html#ga8a0329d37cc43403ca07722129e315d8',1,'Ogre::PbsMaterial::TextureAddressing::u()']]],
  ['uncompressedsize',['uncompressedSize',['../struct_ogre_1_1_file_info.html#a66c7bf4f59feb619016a5c70e4ded4ee',1,'Ogre::FileInfo']]],
  ['uninitialized_5fcollapse_5fcost',['UNINITIALIZED_COLLAPSE_COST',['../struct_ogre_1_1_lod_data.html#af95ac40c4f3bdd402aa2e0cc1e25fc9c',1,'Ogre::LodData']]],
  ['unit_5fscale',['UNIT_SCALE',['../struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#a979837f10b7068528efc6802742f5509',1,'Ogre::VectorBase&lt; 2, Real &gt;::UNIT_SCALE()'],['../struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a89fbc371d11d0363db247d6ef1fa7afa',1,'Ogre::VectorBase&lt; 3, Real &gt;::UNIT_SCALE()']]],
  ['unit_5fx',['UNIT_X',['../struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#adeeb454e50949d89f71b52a38e52951e',1,'Ogre::VectorBase&lt; 2, Real &gt;::UNIT_X()'],['../struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a2fe25096ba980b3569e44833ddf155e6',1,'Ogre::VectorBase&lt; 3, Real &gt;::UNIT_X()']]],
  ['unit_5fy',['UNIT_Y',['../struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#ab771b243b99665aaff02505c273be9ee',1,'Ogre::VectorBase&lt; 2, Real &gt;::UNIT_Y()'],['../struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a25a0d767f153bc408453ee85de866c87',1,'Ogre::VectorBase&lt; 3, Real &gt;::UNIT_Y()']]],
  ['unit_5fz',['UNIT_Z',['../struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#ab8448c3f1c0a210e465a1aa0e551a33a',1,'Ogre::VectorBase&lt; 3, Real &gt;']]],
  ['unknown',['unknown',['../structbsp__face__t.html#adf2e01928d721064f72ba3f9c2e6a2fd',1,'bsp_face_t']]],
  ['updatefrom',['updateFrom',['../struct_ogre_1_1_volume_1_1_chunk_parameters.html#aeefacd1d618206fcb432ed947b58e06e',1,'Ogre::Volume::ChunkParameters']]],
  ['updateto',['updateTo',['../struct_ogre_1_1_volume_1_1_chunk_parameters.html#afe30999e8cc71a1f48d87d68bf43059d',1,'Ogre::Volume::ChunkParameters']]],
  ['usebackgroundqueue',['useBackgroundQueue',['../struct_ogre_1_1_lod_config_1_1_advanced.html#af0b0ebeed034ed3d63ea1bfc3c36fab0',1,'Ogre::LodConfig::Advanced']]],
  ['usecompression',['useCompression',['../struct_ogre_1_1_lod_config_1_1_advanced.html#a170e01ea28652c19ec4d610c0b491ab7',1,'Ogre::LodConfig::Advanced']]],
  ['usedcount',['usedCount',['../struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#a433c84c8a42109d4f1e0987c063b0eee',1,'Ogre::Lod0Stripifier::RemapInfo']]],
  ['usefullscreen',['useFullScreen',['../struct_ogre_1_1_render_window_description.html#a5809e1727a29bbc2737e090ab338c6a7',1,'Ogre::RenderWindowDescription']]],
  ['useglobalinstancingvertexbufferisavailable',['useGlobalInstancingVertexBufferIsAvailable',['../class_ogre_1_1_render_operation.html#a58effcf80fb468f10360aeab08d3c32e',1,'Ogre::RenderOperation']]],
  ['useindexes',['useIndexes',['../class_ogre_1_1_render_operation.html#ae12d3ff9f224f21738fa50f832484f3d',1,'Ogre::RenderOperation']]],
  ['user_5ftype_5fmask_5flimit',['USER_TYPE_MASK_LIMIT',['../class_ogre_1_1_scene_manager.html#a01d4bf3c6e81fddcfc96ec3f2714c8ac',1,'Ogre::SceneManager']]],
  ['uservalue',['userValue',['../struct_ogre_1_1_mesh_lod_usage.html#a114e1bc321b7b64f5bc931a30fea4dfe',1,'Ogre::MeshLodUsage']]],
  ['usesharedvertexbuffer',['useSharedVertexBuffer',['../struct_ogre_1_1_lod_input_buffer_1_1_submesh.html#a575926e31feb1cc9bfebab8a13fded97',1,'Ogre::LodInputBuffer::Submesh']]],
  ['usesharedvertices',['useSharedVertices',['../class_ogre_1_1_sub_mesh.html#a931e3764e3bf1c3ef7431fc852770fb1',1,'Ogre::SubMesh']]],
  ['usevertexnormals',['useVertexNormals',['../struct_ogre_1_1_lod_config_1_1_advanced.html#aa510662a645fab3ef85ef4b1cde1a7a2',1,'Ogre::LodConfig::Advanced']]],
  ['uvcount',['UvCount',['../group___hlms.html#ga6fb7180418134082f76431b6bedcdd62',1,'Ogre::DefaultProperties']]],
  ['uvcount0',['UvCount0',['../group___hlms.html#gaedab28b78e0ebc409cf4d3101a67af7c',1,'Ogre::DefaultProperties']]],
  ['uvcount1',['UvCount1',['../group___hlms.html#ga5483f4f1b66ed2f133e440367cab75d4',1,'Ogre::DefaultProperties']]],
  ['uvcount2',['UvCount2',['../group___hlms.html#ga47f8e565c0a2e5ccf4e24bc67e2706d2',1,'Ogre::DefaultProperties']]],
  ['uvcount3',['UvCount3',['../group___hlms.html#ga8439416753af467b73c4e8bbb70d44cc',1,'Ogre::DefaultProperties']]],
  ['uvcount4',['UvCount4',['../group___hlms.html#ga0fc23b194d9420e5b0b3c75b279e2e3c',1,'Ogre::DefaultProperties']]],
  ['uvcount5',['UvCount5',['../group___hlms.html#ga124b240dea2798f2c50151181e6c5678',1,'Ogre::DefaultProperties']]],
  ['uvcount6',['UvCount6',['../group___hlms.html#gaeb807ee11ed0edae44300ee8ef38bcf5',1,'Ogre::DefaultProperties']]],
  ['uvcount7',['UvCount7',['../group___hlms.html#gadd3f91003e10f2fe9efacecb4faed9f6',1,'Ogre::DefaultProperties']]],
  ['uvcountptrs',['UvCountPtrs',['../group___hlms.html#ga664c90b0d92acd45c06a39a3f259ad49',1,'Ogre::DefaultProperties']]],
  ['uvrect',['uvRect',['../struct_ogre_1_1_font_1_1_glyph_info.html#a46b20f8f199e3d2f698aa44a6553ab50',1,'Ogre::Font::GlyphInfo']]]
];
